# Licensed under a 3-clause BSD style license, see LICENSE.
"""
This module `hepunits.constants` contains 2 sorts of constants:

  * Physical constants.
  * Common and/or handy constants.

All constants are computed in the HEP System of Units
as defined in the `hepunits.units` package.

Typical use case::

    >>> from hepunits.constants import c_light
    >>> from hepunits.units     import picosecond, micrometer
    >>> tau_Bs = 1.5 * picosecond    # a particle lifetime, say the Bs meson's
    >>> ctau_Bs = c_light * tau_Bs   # ctau of the particle, ~450 microns
    >>> print ctau_Bs                # result in HEP units, so mm ;-)
    0.449688687
    >>> print ctau_Bs / micrometer   # result in micrometers
    449.688687

"""

from .constants import *



# Licensed under a 3-clause BSD style license, see LICENSE.
"""
Subpackage for the HEP System of Units, (derived) physical units
and commonly-used unit prefixes.

The HEP System of Units is the set of basic units originally defined by the CLHEP project.
"""

from .prefixes import *
from .units import *



# Licensed under a 3-clause BSD style license, see LICENSE.

# Convenient access to the version number
from .version import version as __version__

# Units and constants directly available
from .units import *
from .constants import *



#!/usr/bin/env python
# Licensed under a 3-clause BSD style license, see LICENSE.
"""
Tests for the hepunits.units.prefixes module.
"""

from pytest import approx

from math import log

from hepunits import mega, micro, yotta, yocto, kibi, tebi


def test_prefixes_e6():
    assert 4 * mega == 1.0 / 0.25 / micro


def test_prefixes_e24():
    assert yotta * yocto == approx(1.0)


def test_prefixes_binary():
    assert log(kibi, 2) == 10
    assert log(tebi, 2) == 40
